<!--next-version-placeholder-->

## v0.6.1 (2022-02-05)
### Fix
* Bug with ImageBoundingBoxDetectionSample.pascal_voc_bboxes not transforming bboxes from COCO -> Pascal VOC correctly ([`a7e3bce`](https://github.com/kevinlu1211/roheboam/commit/a7e3bcebc626e8cf580868337077e85060a40841))

## v0.6.0 (2022-01-31)
### Feature
* Added remove by tag when running pipeline and different propagation modes ([`acff817`](https://github.com/kevinlu1211/roheboam/commit/acff817265fe6faa7bd26e1dd7f4a98a0bd13f78))

## v0.5.0 (2022-01-25)

### Feature

- Function to config ([`23be263`](https://github.com/kevinlu1211/roheboam/commit/23be2630e5ce2bb2767eecd7fd5a85ccb2215381))
